==> cause_effect-0.1.0.tar.gz: cause_effect-0.1.0/setup.py <==
from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

setup(
    name='cause_effect',
    version='0.1.0',
    description="A library for cause-effect relationships.",
    long_description=readme + '\n\n' + history,
    author="Benjamin Weber",
    author_email='mail@bwe.im',
    url='http://bitbucket.com/hyllos/pareto-python',
    py_modules=[
        'casue_effect',
    ],
    license="MIT license",
    zip_safe=False,
    include_package_data=True,
    keywords='pareto cause-effect power-law entropy',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Customer Service',
        'Intended Audience :: Financial and Insurance Industry',
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Manufacturing',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Telecommunications Industry',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ]
)

==> cause_effect-0.2.0.tar.gz: cause_effect-0.2.0/setup.py <==
from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

setup(
    name='cause_effect',
    version='0.2.0',
    description="A library for cause-effect relationships.",
    long_description=readme + '\n\n' + history,
    author="Benjamin Weber",
    author_email='mail@bwe.im',
    url='http://bitbucket.com/hyllos/cause_effect',
    py_modules=[
        'casue_effect',
    ],
    license="MIT license",
    zip_safe=False,
    include_package_data=True,
    keywords='pareto cause-effect power-law entropy',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Customer Service',
        'Intended Audience :: Financial and Insurance Industry',
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Manufacturing',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Telecommunications Industry',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ]
)
